@@ -1085,6 +1085,7 @@ Please review the page and save then. Do not save this page as it is!""")
             raise self.EditConflict, msg
         elif newtext == self.get_raw_body():
             msg = _('You did not change the page content, not saved!')
+            self.lock.release()
             raise self.Unchanged, msg
         else:
             from MoinMoin.security import parseACL
@@ -1295,7 +1296,7 @@ To leave the editor, press the Cancel button.""", wiki=True) % {
         """ Write new lock file. """
         self._deleteLockFile()
         try:
-            editlog.EditLog(self.request, filename=self._filename()).add(
+            editlog.EditLog(self.request, filename=self._filename(), force_ip=True).add(
                self.request, wikiutil.timestamp2version(self.now), 0, "LOCK", self.page_name)
         except IOError:
             pass
