@@ -24,20 +24,20 @@ def execute(pagename, request):
 
     # Error?
     if isinstance(matches, (str, unicode)):
-        Page(request, pagename).send_page(msg=matches)
+        request.theme.add_msg(matches, "info")
+        Page(request, pagename).send_page()
         return
 
     # No matches
     if not matches:
-        Page(request, pagename).send_page(
-             msg=_('No pages like "%s"!', formatted=False) % (pagename,))
+        request.theme.add_msg(_('No pages like "%s"!') % (pagename, ), "error")
+        Page(request, pagename).send_page()
         return
 
     # One match - display it
     if len(matches) == 1:
-        Page(request, matches.keys()[0]).send_page(
-             msg=_('Exactly one page like "%s" found, redirecting to page.', formatted=False) % (
-            pagename,))
+        request.theme.add_msg(_('Exactly one page like "%s" found, redirecting to page.') % (pagename, ), "info")
+        Page(request, matches.keys()[0]).send_page()
         return
 
     # more than one match, list 'em
@@ -46,7 +46,7 @@ def execute(pagename, request):
     # This action generate data using the user language
     request.setContentLanguage(request.lang)
 
-    request.theme.send_title(_('Pages like "%s"', formatted=False) % (pagename), pagename=pagename)
+    request.theme.send_title(_('Pages like "%s"') % (pagename), pagename=pagename)
 
     # Start content - IMPORTANT - without content div, there is no
     # direction support!
@@ -59,9 +59,9 @@ def execute(pagename, request):
     request.theme.send_footer(pagename)
     request.theme.send_closing_html()
 
-def findMatches(pagename, request, s_re=None, e_re=None,):
+def findMatches(pagename, request, s_re=None, e_re=None):
     """ Find like pages
-    
+
     @param pagename: name to match
     @param request: current reqeust
     @param s_re: start re for wiki matching
@@ -207,8 +207,8 @@ def showMatches(pagename, request, start, end, matches, show_count=True):
     _showMatchGroup(request, matches, keys, 8, pagename, show_count)
     _showMatchGroup(request, matches, keys, 4, "%s/..." % pagename, show_count)
     _showMatchGroup(request, matches, keys, 3, "%s...%s" % (start, end), show_count)
-    _showMatchGroup(request, matches, keys, 1, "%s..." % (start,), show_count)
-    _showMatchGroup(request, matches, keys, 2, "...%s" % (end,), show_count)
+    _showMatchGroup(request, matches, keys, 1, "%s..." % (start, ), show_count)
+    _showMatchGroup(request, matches, keys, 2, "...%s" % (end, ), show_count)
 
 
 def _showMatchGroup(request, matches, keys, match, title, show_count=True):
@@ -220,10 +220,11 @@ def _showMatchGroup(request, matches, keys, match, title, show_count=True):
             # Render title line
             request.write(request.formatter.paragraph(1))
             request.write(request.formatter.strong(1))
-            request.write(_('%(matchcount)d %(matches)s for "%(title)s"', formatted=False) % {
-                'matchcount': matchcount,
-                'matches': ' ' + (_('match', formatted=False), _('matches', formatted=False))[matchcount != 1],
-                'title': wikiutil.escape(title)})
+            request.write(request.formatter.text(
+                _('%(matchcount)d %(matches)s for "%(title)s"') % {
+                    'matchcount': matchcount,
+                    'matches': ' ' + (_('match'), _('matches'))[matchcount != 1],
+                    'title': title}))
             request.write(request.formatter.strong(0))
             request.write(request.formatter.paragraph(0))
 
