@@ -362,6 +362,9 @@ class ConfigFunctionality(object):
         if self.url_prefix_local is None:
             self.url_prefix_local = self.url_prefix_static
 
+        if self.url_prefix_fckeditor is None:
+            self.url_prefix_fckeditor = self.url_prefix_local + '/applets/FCKeditor'
+
         if self.secrets is None:  # admin did not setup a real secret, so make up something
             self.secrets = self.calc_secrets()
 
@@ -755,13 +758,13 @@ options_no_group_name = {
         'AttachFile': (90, 60),
         'cache': (600, 30), # cache action is very cheap/efficient
      },
-     "Surge protection tries to deny clients causing too much load/traffic, see /SurgeProtection."),
+     "Surge protection tries to deny clients causing too much load/traffic, see HelpOnConfiguration/SurgeProtection."),
     ('surge_lockout_time', 3600, "time [s] someone gets locked out when ignoring the warnings"),
 
     ('textchas', None,
      "Spam protection setup using site-specific questions/answers, see HelpOnTextChas."),
     ('textchas_disabled_group', None,
-     "Name of a group of trusted users who do not get asked TextCha questions."),
+     "Name of a group of trusted users who do not get asked !TextCha questions."),
 
     ('antispam_master_url', "http://master.moinmo.in/?action=xmlrpc2",
      "where antispam security policy fetches spam pattern updates (if it is enabled)"),
@@ -843,6 +846,16 @@ options_no_group_name = {
     ('traceback_show', True,
      "if True, show debug tracebacks to users when moin crashes"),
 
+    ('packagepages_actions_excluded',
+     ['setthemename',  # related to questionable theme stuff, see below
+      'copythemefile', # maybe does not work, e.g. if no fs write permissions or real theme file path is unknown to moin
+      'installplugin', # code installation, potentially dangerous
+      'renamepage',    # dangerous with hierarchical acls
+      'deletepage',    # dangerous with hierarchical acls
+      'delattachment', # dangerous, no revisioning
+     ],
+     'list with excluded package actions (e.g. because they are dangerous / questionable)'),
+
     ('page_credits',
      [
        '<a href="http://moinmo.in/" title="This site uses the MoinMoin Wiki software.">MoinMoin Powered</a>',
@@ -911,6 +924,8 @@ options_no_group_name = {
      "used as the base URL for icons, css, etc. - includes the moin version number and changes on every release. This replaces the deprecated and sometimes confusing `url_prefix = '/wiki'` setting."),
     ('url_prefix_local', None,
      "used as the base URL for some Javascript - set this to a URL on same server as the wiki if your url_prefix_static points to a different server."),
+    ('url_prefix_fckeditor', None,
+     "used as the base URL for FCKeditor - similar to url_prefix_local, but just for FCKeditor."),
 
     ('url_prefix_action', None,
      "Use 'action' to enable action URL generation to be compatible with robots.txt. It will generate .../action/info/PageName?action=info then. Recommended for internet wikis."),
@@ -1116,7 +1131,7 @@ options = {
         # id -> username for page info and recent changes, but it
         # is not usable for the user any more:
        ],
-       "Describes user preferences, see /UserPreferences."),
+       "Describes user preferences, see HelpOnConfiguration/UserPreferences."),
 
       ('checkbox_defaults',
        {
@@ -1132,13 +1147,13 @@ options = {
         'wikiname_add_spaces': 0,
         'remember_me': 1,
        },
-       "Defaults for user preferences, see /UserPreferences."),
+       "Defaults for user preferences, see HelpOnConfiguration/UserPreferences."),
 
       ('checkbox_disable', [],
-       "Disable user preferences, see /UserPreferences."),
+       "Disable user preferences, see HelpOnConfiguration/UserPreferences."),
 
       ('checkbox_remove', [],
-       "Remove user preferences, see /UserPreferences."),
+       "Remove user preferences, see HelpOnConfiguration/UserPreferences."),
 
       ('form_fields',
        [
@@ -1202,7 +1217,7 @@ options = {
       ('compression', 'gz', 'What compression to use for the backup ("gz" or "bz2").'),
       ('users', [], 'List of trusted user names who are allowed to get a backup.'),
       ('include', [], 'List of pathes to backup.'),
-      ('exclude', lambda filename: False, 'Function f(filename) that tells whether a file should be excluded from backup. By default, nothing is excluded.'),
+      ('exclude', lambda self, filename: False, 'Function f(self, filename) that tells whether a file should be excluded from backup. By default, nothing is excluded.'),
     )),
 }
 
