@@ -2,17 +2,19 @@
 """
     MoinMoin - xapian search engine
 
-    @copyright: 2006 MoinMoin:ThomasWaldmann,
+    @copyright: 2006-2008 MoinMoin:ThomasWaldmann,
                 2006 MoinMoin:FranzPletz
     @license: GNU GPL, see COPYING for details.
 """
-debug = True
 
 import os, re
 
 import xapian
 from xapian import Query
 
+from MoinMoin import log
+logging = log.getLogger(__name__)
+
 from MoinMoin.support.xapwrap import document as xapdoc
 from MoinMoin.support.xapwrap import index as xapidx
 from MoinMoin.parser.text_moin_wiki import Parser as WikiParser
@@ -21,12 +23,6 @@ from MoinMoin.Page import Page
 from MoinMoin import config, wikiutil
 from MoinMoin.search.builtin import BaseIndex
 
-try:
-    # PyStemmer, snowball python bindings from http://snowball.tartarus.org/
-    from Stemmer import Stemmer
-except ImportError:
-    Stemmer = None
-
 
 class UnicodeQuery(Query):
     """ Xapian query object which automatically encodes unicode strings """
@@ -61,7 +57,7 @@ def getWikiAnalyzerFactory(request=None, language='en'):
 
 class WikiAnalyzer:
     """ A text analyzer for wiki syntax
-    
+
     The purpose of this class is to anaylze texts/pages in wiki syntax
     and yield yielding single terms for xapwrap to feed into the xapian
     database.
@@ -73,19 +69,18 @@ class WikiAnalyzer:
                  }
 
     singleword_re = re.compile(singleword, re.U)
-    wikiword_re = re.compile(WikiParser.word_rule, re.U)
+    wikiword_re = re.compile(WikiParser.word_rule, re.UNICODE|re.VERBOSE)
 
     token_re = re.compile(
         r"(?P<company>\w+[&@]\w+)|" + # company names like AT&T and Excite@Home.
         r"(?P<email>\w+([.-]\w+)*@\w+([.-]\w+)*)|" +    # email addresses
-        r"(?P<hostname>\w+(\.\w+)+)|" +                 # hostnames
-        r"(?P<num>(\w+[-/.,])*\w*\d\w*([-/.,]\w+)*)|" + # version numbers
         r"(?P<acronym>(\w\.)+)|" +          # acronyms: U.S.A., I.B.M., etc.
         r"(?P<word>\w+)",                   # words (including WikiWords)
         re.U)
 
     dot_re = re.compile(r"[-_/,.]")
     mail_re = re.compile(r"[-_/,.]|(@)")
+    alpha_num_re = re.compile(r"\d+|\D+")
 
     # XXX limit stuff above to xapdoc.MAX_KEY_LEN
     # WORD_RE = re.compile('\\w{1,%i}' % MAX_KEY_LEN, re.U)
@@ -95,56 +90,60 @@ class WikiAnalyzer:
         @param request: current request
         @param language: if given, the language in which to stem words
         """
+        self.stemmer = None
         if request and request.cfg.xapian_stemming and language:
-            self.stemmer = Stemmer(language)
+            try:
+                stemmer = xapian.Stem(language)
+                # we need this wrapper because the stemmer returns a utf-8
+                # encoded string even when it gets fed with unicode objects:
+                self.stemmer = lambda word: stemmer(word).decode('utf-8')
+            except xapian.InvalidArgumentError:
+                # lang is not stemmable or not available
+                pass
+
+    def raw_tokenize_word(self, word, pos):
+        """ try to further tokenize some word starting at pos """
+        yield (word, pos)
+        if self.wikiword_re.match(word):
+            # if it is a CamelCaseWord, we additionally try to tokenize Camel, Case and Word
+            for m in re.finditer(self.singleword_re, word):
+                mw, mp = m.group(), pos + m.start()
+                for w, p in self.raw_tokenize_word(mw, mp):
+                    yield (w, p)
         else:
-            self.stemmer = None
+            # if we have Foo42, yield Foo and 42
+            for m in re.finditer(self.alpha_num_re, word):
+                mw, mp = m.group(), pos + m.start()
+                if mw != word:
+                    for w, p in self.raw_tokenize_word(mw, mp):
+                        yield (w, p)
+
 
     def raw_tokenize(self, value):
-        """ Yield a stream of lower cased raw and stemmed words from a string.
+        """ Yield a stream of words from a string.
 
         @param value: string to split, must be an unicode object or a list of
                       unicode objects
         """
-        def enc(uc):
-            """ 'encode' unicode results into whatever xapian wants """
-            lower = uc.lower()
-            return lower
-
         if isinstance(value, list): # used for page links
             for v in value:
-                yield (enc(v), 0)
+                yield (v, 0)
         else:
             tokenstream = re.finditer(self.token_re, value)
             for m in tokenstream:
                 if m.group("acronym"):
-                    yield (enc(m.group("acronym").replace('.', '')),
-                            m.start())
+                    yield (m.group("acronym").replace('.', ''), m.start())
                 elif m.group("company"):
-                    yield (enc(m.group("company")), m.start())
+                    yield (m.group("company"), m.start())
                 elif m.group("email"):
                     displ = 0
                     for word in self.mail_re.split(m.group("email")):
                         if word:
-                            yield (enc(word), m.start() + displ)
+                            yield (word, m.start() + displ)
                             displ += len(word) + 1
-                elif m.group("hostname"):
-                    displ = 0
-                    for word in self.dot_re.split(m.group("hostname")):
-                        yield (enc(word), m.start() + displ)
-                        displ += len(word) + 1
-                elif m.group("num"):
-                    displ = 0
-                    for word in self.dot_re.split(m.group("num")):
-                        yield (enc(word), m.start() + displ)
-                        displ += len(word) + 1
                 elif m.group("word"):
-                    word = m.group("word")
-                    yield (enc(word), m.start())
-                    # if it is a CamelCaseWord, we additionally yield Camel, Case and Word
-                    if self.wikiword_re.match(word):
-                        for sm in re.finditer(self.singleword_re, word):
-                            yield (enc(sm.group()), m.start() + sm.start())
+                    for word, pos in self.raw_tokenize_word(m.group("word"), m.start()):
+                        yield word, pos
 
     def tokenize(self, value, flat_stemming=True):
         """ Yield a stream of lower cased raw and stemmed words from a string.
@@ -156,12 +155,13 @@ class WikiAnalyzer:
                                 yield both at once as a tuple (False)
         """
         for word, pos in self.raw_tokenize(value):
+            word = word.lower() # transform it into what xapian wants
             if flat_stemming:
                 yield (word, pos)
                 if self.stemmer:
-                    yield (self.stemmer.stemWord(word), pos)
+                    yield (self.stemmer(word), pos)
             else:
-                yield (word, self.stemmer.stemWord(word), pos)
+                yield (word, self.stemmer(word), pos)
 
 
 #############################################################################
@@ -213,18 +213,11 @@ class Index(BaseIndex):
         self._check_version()
         BaseIndex.__init__(self, request)
 
-        # Check if we should and can stem words
-        if request.cfg.xapian_stemming and not Stemmer:
-            request.cfg.xapian_stemming = False
-
     def _check_version(self):
         """ Checks if the correct version of Xapian is installed """
         # every version greater than or equal to XAPIAN_MIN_VERSION is allowed
-        XAPIAN_MIN_VERSION = (0, 9, 6)
-        try:
-           major, minor, revision = xapian.major_version(), xapian.minor_version(), xapian.revision()
-        except AttributeError:
-           major, minor, revision = xapian.xapian_major_version(), xapian.xapian_minor_version(), xapian.xapian_revision() # deprecated since xapian 0.9.6, removal in 1.1.0
+        XAPIAN_MIN_VERSION = (1, 0, 0)
+        major, minor, revision = xapian.major_version(), xapian.minor_version(), xapian.revision()
         if (major, minor, revision) >= XAPIAN_MIN_VERSION:
             return
 
@@ -248,7 +241,7 @@ class Index(BaseIndex):
 
     def _search(self, query, sort='weight', historysearch=0):
         """ Perform the search using xapian (read-lock acquired)
-        
+
         @param query: the search query objects
         @keyword sort: the sorting of the results (default: 'weight')
         @keyword historysearch: whether to search in all page revisions (default: 0) TODO: use/implement this
@@ -289,12 +282,7 @@ class Index(BaseIndex):
         # do all page updates
         pages = self.update_queue.pages()[:amount]
         for name in pages:
-            p = Page(request, name)
-            if request.cfg.xapian_index_history:
-                for rev in p.getRevList():
-                    self._index_page(writer, Page(request, name, rev=rev), mode='update')
-            else:
-                self._index_page(writer, p, mode='update')
+            self._index_page(request, writer, name, mode='update')
             self.update_queue.remove([name])
 
         # do page/attachment removals
@@ -302,7 +290,7 @@ class Index(BaseIndex):
         for item in items:
             _item = item.split('//')
             p = Page(request, _item[0])
-            self._remove_item(writer, p, _item[1])
+            self._remove_item(request, writer, p, _item[1])
             self.remove_queue.remove([item])
 
         writer.close()
@@ -317,7 +305,7 @@ class Index(BaseIndex):
 
     def termpositions(self, uid, term):
         """ Fetches all positions of a term in a document
-        
+
         @param uid: document id of the item in the xapian index
         @param term: the term as a string
         """
@@ -334,7 +322,7 @@ class Index(BaseIndex):
         fs_rootpage = 'FS' # XXX FS hardcoded
 
         try:
-            wikiname = request.cfg.interwikiname or 'Self'
+            wikiname = request.cfg.interwikiname or u'Self'
             itemid = "%s:%s" % (wikiname, os.path.join(fs_rootpage, filename))
             mtime = os.path.getmtime(filename)
             mtime = wikiutil.timestamp2version(mtime)
@@ -346,40 +334,40 @@ class Index(BaseIndex):
                     uid = doc['uid']
                     docmtime = long(doc['values']['mtime'])
                     updated = mtime > docmtime
-                    if debug: request.log("uid %r: mtime %r > docmtime %r == updated %r" % (uid, mtime, docmtime, updated))
+                    logging.debug("uid %r: mtime %r > docmtime %r == updated %r" % (uid, mtime, docmtime, updated))
                 else:
                     uid = None
                     updated = True
             elif mode == 'add':
                 updated = True
-            if debug: request.log("%s %r" % (filename, updated))
+            logging.debug("%s %r" % (filename, updated))
             if updated:
                 xitemid = xapdoc.Keyword('itemid', itemid)
                 mimetype, file_content = self.contentfilter(filename)
-                xwname = xapdoc.SortKey('wikiname', request.cfg.interwikiname or "Self")
+                xwname = xapdoc.SortKey('wikiname', request.cfg.interwikiname or u"Self")
                 xpname = xapdoc.SortKey('pagename', fs_rootpage)
                 xattachment = xapdoc.SortKey('attachment', filename) # XXX we should treat files like real pages, not attachments
-                xmtime = xapdoc.SortKey('mtime', mtime)
+                xmtime = xapdoc.SortKey('mtime', str(mtime))
                 xrev = xapdoc.SortKey('revision', '0')
                 title = " ".join(os.path.join(fs_rootpage, filename).split("/"))
                 xtitle = xapdoc.Keyword('title', title)
-                xmimetype = xapdoc.TextField('mimetype', mimetype, True)
+                xmimetypes = [xapdoc.Keyword('mimetype', mt) for mt in [mimetype, ] + mimetype.split('/')]
                 xcontent = xapdoc.TextField('content', file_content)
-                doc = xapdoc.Document(textFields=(xcontent, xmimetype, ),
-                                      keywords=(xtitle, xitemid, ),
+                doc = xapdoc.Document(textFields=(xcontent, ),
+                                      keywords=xmimetypes + [xtitle, xitemid, ],
                                       sortFields=(xpname, xattachment,
                                           xmtime, xwname, xrev, ),
                                      )
                 doc.analyzerFactory = getWikiAnalyzerFactory()
                 if mode == 'update':
-                    if debug: request.log("%s (replace %r)" % (filename, uid))
+                    logging.debug("%s (replace %r)" % (filename, uid))
                     doc.uid = uid
                     id = writer.index(doc)
                 elif mode == 'add':
-                    if debug: request.log("%s (add)" % (filename,))
+                    logging.debug("%s (add)" % (filename, ))
                     id = writer.index(doc)
-        except (OSError, IOError):
-            pass
+        except (OSError, IOError, UnicodeError):
+            logging.exception("_index_file crashed:")
 
     def _get_languages(self, page):
         """ Get language of a page and the language to stem it in
@@ -389,24 +377,17 @@ class Index(BaseIndex):
         lang = None
         default_lang = page.request.cfg.language_default
 
-        # if we should stem, we check if we have stemmer for the
-        # language available
+        # if we should stem, we check if we have stemmer for the language available
         if page.request.cfg.xapian_stemming:
             lang = page.pi['language']
-            # Stemmer(lang) has an exception bug if the language is not available
-            # TypeError: exceptions must be strings, classes, or instances, not exceptions.KeyError
             try:
-                Stemmer(lang)
+                xapian.Stem(lang)
                 # if there is no exception, lang is stemmable
                 return (lang, lang)
-            except KeyError:
+            except xapian.InvalidArgumentError:
                 # lang is not stemmable
                 pass
-            except TypeError:
-                # Stemmer(lang) has an exception bug if the language is not available
-                # TypeError: exceptions must be strings, classes, or instances, 
-                pass
-    
+
         if not lang:
             # no lang found at all.. fallback to default language
             lang = default_lang
@@ -427,13 +408,12 @@ class Index(BaseIndex):
         while next:
             if next != 1:
                 pos += next.end()
-            prev, next = next, re.search(r'----*\r?\n', body[pos:])
+            prev, next = next, re.search(r'-----*\s*\r?\n', body[pos:])
 
         if not prev or prev == 1:
             return []
-
-        return [cat.lower()
-                for cat in re.findall(r'Category([^\s]+)', body[pos:])]
+        # for CategoryFoo, group 'all' matched CategoryFoo, group 'key' matched just Foo
+        return [m.group('all').lower() for m in self.request.cfg.cache.page_category_regex.finditer(body[pos:])]
 
     def _get_domains(self, page):
         """ Returns a generator with all the domains the page belongs to
@@ -447,21 +427,101 @@ class Index(BaseIndex):
         if wikiutil.isSystemPage(self.request, page.page_name):
             yield 'system'
 
-    def _index_page(self, writer, page, mode='update'):
+    def _index_page(self, request, writer, pagename, mode='update'):
         """ Index a page - assumes that the write lock is acquired
 
+        @arg writer: the index writer object
+        @arg pagename: a page name
+        @arg mode: 'add' = just add, no checks
+                   'update' = check if already in index and update if needed (mtime)
+        """
+        p = Page(request, pagename)
+        if request.cfg.xapian_index_history:
+            for rev in p.getRevList():
+                updated = self._index_page_rev(request, writer, Page(request, pagename, rev=rev), mode=mode)
+                logging.debug("updated page %r rev %d (updated==%r)" % (pagename, rev, updated))
+                if not updated:
+                    # we reached the revisions that are already present in the index
+                    break
+        else:
+            self._index_page_rev(request, writer, p, mode=mode)
+
+        from MoinMoin.action import AttachFile
+        wikiname = request.cfg.interwikiname or u"Self"
+        # XXX: Hack until we get proper metadata
+        language, stem_language = self._get_languages(p)
+        domains = tuple(self._get_domains(p))
+        updated = False
+
+        attachments = AttachFile._get_files(request, pagename)
+        for att in attachments:
+            filename = AttachFile.getFilename(request, pagename, att)
+            att_itemid = "%s:%s//%s" % (wikiname, pagename, att)
+            mtime = wikiutil.timestamp2version(os.path.getmtime(filename))
+            if mode == 'update':
+                query = xapidx.RawQuery(xapdoc.makePairForWrite('itemid', att_itemid))
+                enq, mset, docs = writer.search(query, valuesWanted=['pagename', 'attachment', 'mtime', ])
+                logging.debug("##%r %r" % (filename, docs))
+                if docs:
+                    doc = docs[0] # there should be only one
+                    uid = doc['uid']
+                    docmtime = long(doc['values']['mtime'])
+                    updated = mtime > docmtime
+                    logging.debug("uid %r: mtime %r > docmtime %r == updated %r" % (uid, mtime, docmtime, updated))
+                else:
+                    uid = None
+                    updated = True
+            elif mode == 'add':
+                updated = True
+            logging.debug("%s %s %r" % (pagename, att, updated))
+            if updated:
+                xatt_itemid = xapdoc.Keyword('itemid', att_itemid)
+                xpname = xapdoc.SortKey('pagename', pagename)
+                xwname = xapdoc.SortKey('wikiname', request.cfg.interwikiname or u"Self")
+                xattachment = xapdoc.SortKey('attachment', att) # this is an attachment, store its filename
+                xmtime = xapdoc.SortKey('mtime', str(mtime))
+                xrev = xapdoc.SortKey('revision', '0')
+                xtitle = xapdoc.Keyword('title', '%s/%s' % (pagename, att))
+                xlanguage = xapdoc.Keyword('lang', language)
+                xstem_language = xapdoc.Keyword('stem_lang', stem_language)
+                mimetype, att_content = self.contentfilter(filename)
+                xmimetypes = [xapdoc.Keyword('mimetype', mt) for mt in [mimetype, ] + mimetype.split('/')]
+                xcontent = xapdoc.TextField('content', att_content)
+                xtitle_txt = xapdoc.TextField('title', '%s/%s' % (pagename, att), True)
+                xfulltitle = xapdoc.Keyword('fulltitle', pagename)
+                xdomains = [xapdoc.Keyword('domain', domain) for domain in domains]
+                doc = xapdoc.Document(textFields=(xcontent, xtitle_txt),
+                                      keywords=xdomains + xmimetypes + [xatt_itemid,
+                                          xtitle, xlanguage, xstem_language,
+                                          xfulltitle, ],
+                                      sortFields=(xpname, xattachment, xmtime,
+                                          xwname, xrev, ),
+                                     )
+                doc.analyzerFactory = getWikiAnalyzerFactory(request, stem_language)
+                if mode == 'update':
+                    logging.debug("%s (replace %r)" % (pagename, uid))
+                    doc.uid = uid
+                    id = writer.index(doc)
+                elif mode == 'add':
+                    logging.debug("%s (add)" % (pagename, ))
+                    id = writer.index(doc)
+        #writer.flush()
+
+    def _index_page_rev(self, request, writer, page, mode='update'):
+        """ Index a page revision - assumes that the write lock is acquired
+
         @arg writer: the index writer object
         @arg page: a page object
         @arg mode: 'add' = just add, no checks
                    'update' = check if already in index and update if needed (mtime)
         """
-        request = page.request
-        wikiname = request.cfg.interwikiname or "Self"
+        request.page = page
+        wikiname = request.cfg.interwikiname or u"Self"
         pagename = page.page_name
         mtime = page.mtime_usecs()
         revision = str(page.get_real_rev())
         itemid = "%s:%s:%s" % (wikiname, pagename, revision)
-        author = page.last_edit(request)['editor']
+        author = page.edit_info().get('editor', '?')
         # XXX: Hack until we get proper metadata
         language, stem_language = self._get_languages(page)
         categories = self._get_categories(page)
@@ -479,13 +539,13 @@ class Index(BaseIndex):
                 uid = doc['uid']
                 docmtime = long(doc['values']['mtime'])
                 updated = mtime > docmtime
-                if debug: request.log("uid %r: mtime %r > docmtime %r == updated %r" % (uid, mtime, docmtime, updated))
+                logging.debug("uid %r: mtime %r > docmtime %r == updated %r" % (uid, mtime, docmtime, updated))
             else:
                 uid = None
                 updated = True
         elif mode == 'add':
             updated = True
-        if debug: request.log("%s %r" % (pagename, updated))
+        logging.debug("%s %r" % (pagename, updated))
         if updated:
             xwname = xapdoc.SortKey('wikiname', wikiname)
             xpname = xapdoc.SortKey('pagename', pagename)
@@ -493,13 +553,16 @@ class Index(BaseIndex):
             xmtime = xapdoc.SortKey('mtime', str(mtime))
             xrev = xapdoc.SortKey('revision', revision)
             xtitle = xapdoc.TextField('title', pagename, True) # prefixed
+            mimetype = 'text/%s' % page.pi['format']  # XXX improve this
             xkeywords = [xapdoc.Keyword('itemid', itemid),
                     xapdoc.Keyword('lang', language),
                     xapdoc.Keyword('stem_lang', stem_language),
                     xapdoc.Keyword('fulltitle', pagename),
                     xapdoc.Keyword('revision', revision),
                     xapdoc.Keyword('author', author),
-                ]
+                ] + \
+                [xapdoc.Keyword('mimetype', mt) for mt in [mimetype, ] + mimetype.split('/')]
+
             for pagelink in page.getPageLinks(request):
                 xkeywords.append(xapdoc.Keyword('linkto', pagelink))
             for category in categories:
@@ -516,75 +579,16 @@ class Index(BaseIndex):
                     stem_language)
 
             if mode == 'update':
-                if debug: request.log("%s (replace %r)" % (pagename, uid))
+                logging.debug("%s (replace %r)" % (pagename, uid))
                 doc.uid = uid
                 id = writer.index(doc)
             elif mode == 'add':
-                if debug: request.log("%s (add)" % (pagename,))
+                logging.debug("%s (add)" % (pagename, ))
                 id = writer.index(doc)
+        return updated
 
-        from MoinMoin.action import AttachFile
-
-        attachments = AttachFile._get_files(request, pagename)
-        for att in attachments:
-            filename = AttachFile.getFilename(request, pagename, att)
-            att_itemid = "%s:%s//%s" % (wikiname, pagename, att)
-            mtime = wikiutil.timestamp2version(os.path.getmtime(filename))
-            if mode == 'update':
-                query = xapidx.RawQuery(xapdoc.makePairForWrite('itemid', att_itemid))
-                enq, mset, docs = writer.search(query, valuesWanted=['pagename', 'attachment', 'mtime', ])
-                if debug: request.log("##%r %r" % (filename, docs))
-                if docs:
-                    doc = docs[0] # there should be only one
-                    uid = doc['uid']
-                    docmtime = long(doc['values']['mtime'])
-                    updated = mtime > docmtime
-                    if debug: request.log("uid %r: mtime %r > docmtime %r == updated %r" % (uid, mtime, docmtime, updated))
-                else:
-                    uid = None
-                    updated = True
-            elif mode == 'add':
-                updated = True
-            if debug: request.log("%s %s %r" % (pagename, att, updated))
-            if updated:
-                xatt_itemid = xapdoc.Keyword('itemid', att_itemid)
-                xpname = xapdoc.SortKey('pagename', pagename)
-                xwname = xapdoc.SortKey('wikiname', request.cfg.interwikiname or "Self")
-                xattachment = xapdoc.SortKey('attachment', att) # this is an attachment, store its filename
-                xmtime = xapdoc.SortKey('mtime', mtime)
-                xrev = xapdoc.SortKey('revision', '0')
-                xtitle = xapdoc.Keyword('title', '%s/%s' % (pagename, att))
-                xlanguage = xapdoc.Keyword('lang', language)
-                xstem_language = xapdoc.Keyword('stem_lang', stem_language)
-                mimetype, att_content = self.contentfilter(filename)
-                xmimetype = xapdoc.Keyword('mimetype', mimetype)
-                xcontent = xapdoc.TextField('content', att_content)
-                xtitle_txt = xapdoc.TextField('title',
-                        '%s/%s' % (pagename, att), True)
-                xfulltitle = xapdoc.Keyword('fulltitle', pagename)
-                xdomains = [xapdoc.Keyword('domain', domain)
-                        for domain in domains]
-                doc = xapdoc.Document(textFields=(xcontent, xtitle_txt),
-                                      keywords=xdomains + [xatt_itemid,
-                                          xtitle, xlanguage, xstem_language,
-                                          xmimetype, xfulltitle, ],
-                                      sortFields=(xpname, xattachment, xmtime,
-                                          xwname, xrev, ),
-                                     )
-                doc.analyzerFactory = getWikiAnalyzerFactory(request,
-                        stem_language)
-                if mode == 'update':
-                    if debug: request.log("%s (replace %r)" % (pagename, uid))
-                    doc.uid = uid
-                    id = writer.index(doc)
-                elif mode == 'add':
-                    if debug: request.log("%s (add)" % (pagename,))
-                    id = writer.index(doc)
-        #writer.flush()
-
-    def _remove_item(self, writer, page, attachment=None):
-        request = page.request
-        wikiname = request.cfg.interwikiname or 'Self'
+    def _remove_item(self, request, writer, page, attachment=None):
+        wikiname = request.cfg.interwikiname or u'Self'
         pagename = page.page_name
 
         if not attachment:
@@ -595,7 +599,7 @@ class Index(BaseIndex):
                 'attachment', ])
             for doc in docs:
                 writer.delete_document(doc['uid'])
-                request.log('%s removed from xapian index' %
+                logging.debug('%s removed from xapian index' %
                         doc['values']['pagename'])
         else:
             # Only remove a single attachment
@@ -606,14 +610,14 @@ class Index(BaseIndex):
             if docs:
                 doc = docs[0] # there should be only one
                 writer.delete_document(doc['uid'])
-                request.log('attachment %s from %s removed from index' %
+                logging.debug('attachment %s from %s removed from index' %
                     (doc['values']['attachment'], doc['values']['pagename']))
 
     def _index_pages(self, request, files=None, mode='update'):
         """ Index all pages (and all given files)
-        
+
         This should be called from indexPages or indexPagesInNewThread only!
-        
+
         This may take some time, depending on the size of the wiki and speed
         of the machine.
 
@@ -637,18 +641,11 @@ class Index(BaseIndex):
             writer = xapidx.Index(self.dir, True)
             writer.configure(self.prefixMap, self.indexValueMap)
             pages = request.rootpage.getPageList(user='', exists=1)
-            request.log("indexing all (%d) pages..." % len(pages))
+            logging.debug("indexing all (%d) pages..." % len(pages))
             for pagename in pages:
-                p = Page(request, pagename)
-                if request.cfg.xapian_index_history:
-                    for rev in p.getRevList():
-                        self._index_page(writer,
-                                Page(request, pagename, rev=rev),
-                                mode)
-                else:
-                    self._index_page(writer, p, mode)
+                self._index_page(request, writer, pagename, mode=mode)
             if files:
-                request.log("indexing all files...")
+                logging.debug("indexing all files...")
                 for fname in files:
                     fname = fname.strip()
                     self._index_file(request, writer, fname, mode)
