@@ -79,9 +79,9 @@ class Settings(UserPrefBase):
             if oidreq is None:
                 return 'error', _("No OpenID given.") # ??
 
-            qstr = wikiutil.makeQueryString({'action': 'userprefs',
-                                             'handler': 'oid',
-                                             'oid.return': '1'})
+            qstr = {'action': 'userprefs',
+                    'handler': 'oid',
+                    'oid.return': '1'}
             return_to = request.getQualifiedURL(request.page.url(request, qstr))
             trust_root = request.getBaseURL()
             if oidreq.shouldSendRedirect():
@@ -102,9 +102,9 @@ class Settings(UserPrefBase):
         query = {}
         for key in request.form:
             query[key] = request.form[key][0]
-        qstr = wikiutil.makeQueryString({'action': 'userprefs',
-                                         'handler': 'oid',
-                                         'oid.return': '1'})
+        qstr = {'action': 'userprefs',
+                'handler': 'oid',
+                'oid.return': '1'}
         return_to = request.getQualifiedURL(request.page.url(request, qstr))
         info = oidconsumer.complete(query, return_to)
         if info.status == consumer.FAILURE:
@@ -142,14 +142,15 @@ class Settings(UserPrefBase):
         if self.request.request_method != 'POST':
             return
 
+        if not wikiutil.checkTicket(self.request, form.get('ticket', [''])[0]):
+            return
+
         if form.has_key('remove'):
             return self._handle_remove()
 
         if form.has_key('add'):
             return self._handle_add()
 
-        return
-
     def _make_form(self):
         sn = self.request.getScriptname()
         pi = self.request.getPathinfo()
@@ -157,6 +158,8 @@ class Settings(UserPrefBase):
         _form = html.FORM(action=action)
         _form.append(html.INPUT(type="hidden", name="action", value="userprefs"))
         _form.append(html.INPUT(type="hidden", name="handler", value="oid"))
+        ticket = wikiutil.createTicket(self.request)
+        _form.append(html.INPUT(type="hidden", name="ticket", value=ticket))
         return _form
 
     def _make_row(self, label, cell, **kw):
